toporough.subset <-
function (dem,d.subset,type,ngbr,nform,k.diff){
  #check & get resolution
  res<-(xres(dem)+yres(dem))/2
  #print warning if x and y resolution are deverse, but calculate anyway
  if(yres(dem)!=xres(dem))
  {
  warning("Different raster resolution in x and y direction: (xres+yres)/2 has been used as overall resolution.")  
  }  
  #calculate parameters
  ngbr.sq<-ngbr^2
  n.neigh<-(ngbr-1)/2
  mid.coor<-(ngbr+1)/2 
  #define moving window
  m.ngb<-matrix(1,ngbr,ngbr)
  m.ngb[((ngbr+1)/2),(ngbr+1)/2]<-0
  #get subset cells
  cell.sub<-cellFromXY(dem,d.subset)

  adj<-adjacent(dem,cell.sub,m.ngb,include=T,sorted=T)
  adj<-cbind(adj,vector(length=nrow(adj)))
  adj[,3]<-extract(dem,adj[,2])

  M.dem<-matrix(NA,nrow=length(cell.sub),ncol=ngbr.sq)
  for (i in c(1:length(cell.sub)))
  {
    M.dem[i,]<-adj[adj[,1]==cell.sub[i],3]
  }

  #calculate number of cells
  n.cells.raster<-length(cell.sub)
  #define distance matrix M.dist
  M1.dist<-matrix(1:ngbr,ncol = ngbr, nrow = ngbr, byrow = T)
  M2.dist<-matrix(1:ngbr,ncol = ngbr, nrow = ngbr)
  M.dist<-sqrt((M2.dist-M1.dist[mid.coor,mid.coor])*(M2.dist-M1.dist[mid.coor,mid.coor])+(M1.dist-M2.dist[mid.coor,mid.coor])*(M1.dist-M2.dist[mid.coor,mid.coor]))
  #define distances within neighborhood window
  v.dist<-c(M.dist[1:((ngbr.sq-1)/2)])
  M.point.x<-matrix(v.dist,ncol=((ngbr.sq-1)/2),nrow=n.cells.raster,byrow = T)
  M.point.x<-M.point.x*res
  if (nform=="circ") {
    M.dist.circ<-M.dist
    M.dist.circ[M.dist.circ[]>(ngbr-1)/2]<-NA
    v.dist.circ<-c(M.dist.circ[1:(ngbr.sq)])
    v.dist.circ[!is.na(v.dist.circ)]<-1
    M.dem<-t(t(M.dem)*v.dist.circ)
  }
  
  #max & min functions that handle NA values 
  na.max <- function(x) ifelse( !all(is.na(x)), max(x, na.rm=T), NA)
  na.min <- function(x) ifelse( !all(is.na(x)), min(x, na.rm=T), NA)
  #calculate d and k
  M.point.k<-(M.dem[,(ngbr.sq):(((ngbr.sq+1)/2)+1)]-((M.dem[,1:(((ngbr.sq)-1)/2)])))/(-M.point.x*2)
  if (!is.na(k.diff))
  {
    M.point.k<-ifelse(M.point.k>=-k.diff & M.point.k<=k.diff,M.point.k,NA)
  }
  M.point.y<-M.dem[,(ngbr.sq):(((ngbr.sq+1)/2)+1)]
  M.point.d<-M.point.y-((M.point.k*(-M.point.x)))
  #calculate roughness parameter
  M.point.d.ver<-(M.point.d-M.dem[,(ngbr.sq+1)/2])/M.point.x/2
  #get max/min values and position in matrix
  if (type=="min")
  {
    rough<-apply(M.point.d.ver,1,na.min)
    rough.pos<-as.numeric(apply(M.point.d.ver,1,which.min)) 
  }else{
    rough<-apply(M.point.d.ver,1,na.max)
    rough.pos<-as.numeric(apply(M.point.d.ver,1,which.max))  
  }
  #generate output 
  data<-matrix(NA,ncol=7,nrow=n.cells.raster)
  colnames(data)<-c("X","Y","mri","k","d","dire","width")
  data[,1]<-d.subset[,1]
  data[,2]<-d.subset[,2]
  data[,3]<-rough
  data[,4]<-sqrt((M.point.k[cbind(1:nrow(M.point.k),rough.pos)])^2)
  data[,5]<-M.point.d[cbind(1:nrow(M.point.d),rough.pos)]-extract(dem,d.subset)
  
  #calculate r.dire
  v.dire<-rep(c(rep(-1,(ngbr-1)/2),rep(1,(ngbr+1)/2)),ngbr)
  M1.dire<-matrix(((ngbr-1)/-2):((ngbr-1)/2),ncol = ngbr, nrow = ngbr, byrow = T)
  M2.dire<-(-1)*(matrix(((ngbr-1)/-2):((ngbr-1)/2),ncol = ngbr, nrow = ngbr))
  M.dire<-((M2.dire)/(sqrt(M1.dire^2+M2.dire^2)))
  M.dire<-acos(M.dire)*180/pi
  M.dire<-t(t(M.dire)*v.dire)
  M.dire<-t(M.dire)
  v.dire<-M.dire[1:((ngbr.sq-1)/2)]
  v.dire<-ifelse(v.dire<0,v.dire+180,v.dire)
 
  data[,6]<-v.dire[rough.pos]
  data[,7]<-M.point.x[cbind(1:nrow(M.point.x),rough.pos)]*2
  gc()
  return(data)
}
