\name{ele.slope}
\alias{ele.slope}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Elevation vs. Slope
}
\description{
Calculates slope statistics for binned elevation data from DEMs.
}
\usage{
ele.slope(r.dem, n.bin)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{r.dem}{
A digital elevation model of object type RasterLayer generated by the command raster() in the raster package.
}
  \item{n.bin}{
Numerical, >0, generates elevation intervals for which slope statistics are computed. The range of elevations is divided by n.bin to get the interval range.
}
}
\details{
Calculates mean, median, 1st and 3rd quartile for slopes for elevation intervals. Slope is calculated by the command terrain() from the raster package.
}
\value{
Matrix of computed slope statistics for elevation intervals.
\item{col1 }{Low elevation of interval.}
\item{col2 }{Top elevation of interval.}
\item{col3 }{Mean slope.}
\item{col4 }{median slope}
\item{col5 }{1st quartile}
\item{col6 }{3rd quartile}
}
\references{

}
\author{
Sebastian Baumann
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
raster
}
\examples{
data("work.data",package="lineaDEM") #import data
dem.austria<-work.data[[1]]
slope.stat<-ele.slope(dem.austria,50)
plot((slope.stat[,1]+slope.stat[,2])/2,slope.stat[,3],
xlab="elevation [m]",ylab="slope [m/m]") #plot mean slope
lines((slope.stat[,1]+slope.stat[,2])/2,slope.stat[,3])

## The function is currently defined as
function (r.dem, n.bin) 
{
    r.slope <- terrain(r.dem, opt = "slope")
    r.dem <- r.slope/r.slope * r.dem
    na.max <- function(x) ifelse(!all(is.na(x)), max(x, na.rm = T), 
        NA)
    na.min <- function(x) ifelse(!all(is.na(x)), min(x, na.rm = T), 
        NA)
    min.ele <- na.min(r.dem[])
    max.ele <- na.max(r.dem[])
    range.ele <- max.ele - min.ele
    ele.interval <- seq(min.ele, max.ele, range.ele/n.bin)
    ele <- na.omit(r.dem[])
    slo <- na.omit(r.slope)
    M.ele.slo <- matrix(NA, nrow = (length(ele.interval) - 1), 
        ncol = 7)
    colnames(M.ele.slo) <- c("low", "high", "mean", "median", 
        "25\% percentile", "75\% percentile", "n")
    for (i in c(0:(length(ele.interval) - 1))) {
        stat.summary <- summary(slo[ele >= ele.interval[i] & 
            ele < ele.interval[i + 1]])
        M.ele.slo[i, 7] <- as.numeric(length(slo[ele >= ele.interval[i] & 
            ele < ele.interval[i + 1]]))
        M.ele.slo[i, 6] <- as.numeric(stat.summary["3rd Qu."])
        M.ele.slo[i, 5] <- as.numeric(stat.summary["1st Qu."])
        M.ele.slo[i, 4] <- as.numeric(stat.summary["Median"])
        M.ele.slo[i, 3] <- as.numeric(stat.summary["Mean"])
        M.ele.slo[i, 2] <- as.numeric(ele.interval[i])
        M.ele.slo[i, 1] <- as.numeric(ele.interval[i + 1])
    }
    return(M.ele.slo)
  }
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
