\name{hough.rough}
\alias{hough.rough}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Multiple hough transformation for automated lineament detection for thinned raster maps.
}
\description{
A straight line detection designed for the thinned output of toporough().
}
\usage{
hough.rough(r.th, r.th.points, r.dire, r.rough, angle, bin, dist.th, angle.th)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{r.th}{
RasterLayer of thresholded multi roughness index map from toporough. 
}
  \item{r.th.points}{
RasterLayer of thresholded multi roughness index map from toporough() thinned by extrema.
}
  \item{r.dire}{
RasterLayer of perpendicular orientations from toporough().
}
  \item{r.rough}{
RasterLayer of multi roughness index (mri) map from toporough().
}
  \item{angle}{
Numerical, 0 <= angle <= 90. Maximum abberation angle from r.dire. See details. 
}
  \item{bin}{
Numerical, 0 <= angle <= 180. Defines angle interval, usually between 0.5 and 5. See details
}
  \item{dist.th}{
Numerical,  >0, usually 3 to 10 times resolution of input RasterLayer. Determines by distance if a point of r.th.points builds a detected lineament. 
}
  \item{angle.th}{
Numerical, 0 < angle <= 90. Determines by orientation if a point of r.th.points builds a detected lineament.
}
}
\details{
Multiple hough transformation designed for a modified output of toporough(): The multi roughness index output of toporough() is thresholded and afterwards thinned by extrema(). The perpendicular orientation of the orientation map of toporough() is calculated.
The thinned points within the domains defined by r.th are used to perform a iterative hough transformation. Depending on angle and bin for each of these points different orientated lines through these points are generated and transformed to the hough space.
In the hough space these lines are represented as points. In the hough space the point density of these points representing lines is calculated with the command density.ppp() from the package spatstat. As weights for density.ppp() the multi roughness index is used. As standard deviation of isotropic gaussian smoothing kernel (sigma) density.ppp() 1/n(points) is used. The global maxima of the points density map represents a lineament. This lineament is retransformed to the xy space and depending on dist.th and angle.th points of r.th.points with a distance less then dist.th and within the angle threshold (angle.th) are identified as builders of the lineament. These points are excluded from r.th.points and the process is restarted without these points. If only one point is left in r.th.points or no lineaments are detected anymore the process is ended. The whole porcess is repeated for other domains of r.th.
The lineaments are cut to the extent of r.th, the thresholded multi roughness index map of toporogh().
}
\value{
List of lineaments and vector of roughness parameters.

\item{comp1 }{List of points defining lineaments in 2x2 matrices. col1= X, col2= Y}
\item{comp2 }{Vector of roughness parameters. Mean of all mri values of all points assigned to a certain line}
%% ...
}
\references{
Hough, P.V.C. Method and means for recognizing complex patterns, U.S. Patent 3,069,654, Dec. 18, 1962
}
\author{
Sebastian Baumann
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
spatstat, raster
}
\examples{
data("work.data",package="lineaDEM") #import data
dem.mara<-work.data[[3]]
rough<-toporough(dem.mara,"max",11,"sq",0.09)
rough.th<-rough[[1]]
rough.th[]<-ifelse(rough.th[]>0.03,rough.th[],NA) #apply threshold
rough.th.points<-extrema(rough.th,3,"max") #thin rough.th to point pattern
rough[[4]][]<-ifelse(rough[[4]][]>90,rough[[4]][]-90,
ifelse(rough[[4]][]<=90,rough[[4]][]+90,NA)) #calculate perpendicular oriantations
lineaments<-hough.rough(rough.th,rough.th.points,rough[[4]],rough[[1]],90,1,100,60)
plot(rough.th)
for (i in c(1:length(lineaments[[1]])))
{
plot(lineaments[[1]][[i]],add=TRUE)
}


## The function is currently defined as
function (r.th, r.th.points, r.dire, r.rough, angle, bin, dist.th, 
    angle.th) 
{
    r.th.for.clump <- r.th
    r.th.for.clump[] <- ifelse(is.na(r.th[]), 0, 1)
    r.th.clump <- clump(r.th.for.clump)
    r.points.clump <- r.th.points/r.th.points * r.th.clump
    data.comp <- matrix(NA, ncol = 6, nrow = sum(!is.na(r.th.points[])))
    colnames(data.comp) <- c("x", "y", "id_area", "dire", "rough", 
        "id_line")
    points <- xyFromCell(r.points.clump, which(!is.na(r.points.clump[])))
    data.comp[, 1] <- points[, 1]
    data.comp[, 2] <- points[, 2]
    data.comp[, 3] <- extract(r.points.clump, points)
    data.comp[, 4] <- extract(r.dire, points)
    data.comp[, 5] <- extract(r.rough, points)
    id.area.counts <- as.data.frame(table(data.comp[, 3]))
    id.use <- as.numeric(as.vector(id.area.counts[id.area.counts[, 
        2] > 1, 1]))
    res.max <- max(res(r.th))
    dif.angles <- seq(-angle + bin, angle, bin)
    diag = sqrt(r.th@extent@xmax^2 + r.th@extent@ymax^2) * 2
    linessd <- list()
    rough.pointssd <- list()
    rough.pointss <- list()
    liness <- list()
    for (k in id.use) {
        zone <- r.th.clump
        zone[] <- ifelse(zone[] == k, 1, 0)
        zone[] <- ifelse(is.na(zone[]), 0, zone[])
        if (sum(zone[] == 1) > 10) {
            ext.zone <- extend(zone, c(res.max, res.max), value = 0)
            vec.hull <- tryCatch(rasterToContour(ext.zone), error = function(e) e)
            if (inherits(vec.hull, "error")) 
                next
            points <- data.comp[data.comp[, 3] == k, 1:2]
            dires <- data.comp[data.comp[, 3] == k, 4]
            roughs <- data.comp[data.comp[, 3] == k, 5]
            points[, 1] <- points[, 1] + ((-r.th@extent@xmin - 
                r.th@extent@xmax)/2)
            points[, 2] <- points[, 2] + ((-r.th@extent@ymin - 
                r.th@extent@ymax)/2)
            M.angles.lin <- matrix(NA, ncol = length(dif.angles), 
                nrow = length(dires))
            for (i in c(1:length(dif.angles))) {
                M.angles.lin[, i] <- dires + dif.angles[i]
            }
            M.angles.lin <- ifelse(M.angles.lin < 0, M.angles.lin + 
                180, M.angles.lin)
            M.angles.lin <- ifelse(M.angles.lin > 180, M.angles.lin - 
                180, M.angles.lin)
            x2.dires <- cos(M.angles.lin * pi/180) + points[, 
                1]
            y2.dires <- sin(M.angles.lin * pi/180) + points[, 
                2]
            M.angles.per <- M.angles.lin + 90
            M.angles.per <- ifelse(M.angles.per >= 180, M.angles.per - 
                180, M.angles.per)
            nx.dires.per <- cos(M.angles.per * pi/180)
            ny.dires.per <- sin(M.angles.per * pi/180)
            x.inters <- (points[, 1] * y2.dires - points[, 2] * 
                x2.dires) * (-nx.dires.per)/((points[, 1] - x2.dires) * 
                (-ny.dires.per) - (points[, 2] - y2.dires) * 
                (-nx.dires.per))
            y.inters <- (points[, 1] * y2.dires - points[, 2] * 
                x2.dires) * (-ny.dires.per)/((points[, 1] - x2.dires) * 
                (-ny.dires.per) - (points[, 2] - y2.dires) * 
                (-nx.dires.per))
            phi <- sqrt(x.inters^2 + y.inters^2)
            phi <- ifelse(y.inters < 0, -phi, phi)
            data <- matrix(NA, ncol = 2, nrow = length(M.angles.per))
            data[, 1] <- as.numeric(M.angles.per)
            data[, 2] <- as.numeric(phi)
            M.roughs <- matrix(NA, ncol = ncol(M.angles.per), 
                nrow = nrow(M.angles.per))
            for (i in c(1:ncol(M.roughs))) {
                M.roughs[, i] <- roughs
            }
            rough.pointss <- list()
            liness <- list()
            j = 1
            while (length(points) > 2) {
                p <- SpatialPoints(matrix(c(as.numeric(M.angles.per), 
                  as.numeric(phi)), ncol = 2, nrow = length(phi)))
                p <- as.ppp(p)
                roughs <- as.numeric(M.roughs)
                d <- density.ppp(p, sigma = 1/nrow(points), weights = roughs, 
                  edge = T)
                rd <- raster(d)
                densi <- max(rd[])
                max.dp <- which.max(rd[])
                max.hough <- xyFromCell(rd, which.max(rd[]))
                if (length(max.hough) > 2) {
                  max.hough <- max.hough[1, ]
                }
                x.normal = (max.hough[2] * cos(max.hough[1] * 
                  pi/180))
                y.normal = (max.hough[2] * sin(max.hough[1] * 
                  pi/180))
                x2.normal <- x.normal + cos((max.hough[1] - 90) * 
                  pi/180) * diag
                y2.normal <- y.normal + sin((max.hough[1] - 90) * 
                  pi/180) * diag
                x3.normal <- x.normal - cos((max.hough[1] - 90) * 
                  pi/180) * diag
                y3.normal <- y.normal - sin((max.hough[1] - 90) * 
                  pi/180) * diag
                line <- spLines(matrix(c(x3.normal, x2.normal, 
                  y3.normal, y2.normal), ncol = 2, nrow = 2))
                builder <- which((gDistance(SpatialPoints(points), 
                  line, byid = T) <= dist.th) & ((sqrt((dires - 
                  max.hough[1])^2)) > 90 - angle.th | (sqrt((dires - 
                  max.hough[1])^2)) < 90 + angle.th))
                x2.normal <- x2.normal + (r.th@extent@xmin + 
                  r.th@extent@xmax)/2
                x3.normal <- x3.normal + (r.th@extent@xmin + 
                  r.th@extent@xmax)/2
                y2.normal <- y2.normal + (r.th@extent@ymin + 
                  r.th@extent@ymax)/2
                y3.normal <- y3.normal + (r.th@extent@ymin + 
                  r.th@extent@ymax)/2
                line <- spLines(matrix(c(x3.normal, x2.normal, 
                  y3.normal, y2.normal), ncol = 2, nrow = 2))
                proj4string(line) <- projection(r.th)
                inters.in <- gIntersection(vec.hull[1, ], line)
                if (length(inters.in) > 1) {
                  lines <- list()
                  id.zw <- 1
                  for (m in seq(1, length(inters.in@coords)/2, 
                    2)) {
                    lines[[id.zw]] <- spLines((matrix(c(inters.in@coords[m, 
                      1], inters.in@coords[m + 1, 1], inters.in@coords[m, 
                      2], inters.in@coords[m + 1, 2]), ncol = 2, 
                      nrow = 2)))
                    id.zw <- 1 + id.zw
                  }
                  points.dem <- points[builder, ]
                  roughs.dem <- roughs[builder]
                  if (length(points.dem) > 2) {
                    points.dem[, 1] <- points.dem[, 1] + (r.th@extent@xmin + 
                      r.th@extent@xmax)/2
                    points.dem[, 2] <- points.dem[, 2] + (r.th@extent@ymin + 
                      r.th@extent@ymax)/2
                    o = 1
                    lines2 <- list()
                    n.points <- list()
                    dens <- list()
                    rough.points <- list()
                    for (n in c(1:length(lines))) {
                      if (sum((gDistance(SpatialPoints(points.dem), 
                        lines[[n]], byid = T) <= dist.th)) > 
                        1) {
                        lines2[[o]] <- lines[[n]]
                        n.points[[o]] <- sum((gDistance(SpatialPoints(points.dem), 
                          lines[[n]], byid = T) <= dist.th))
                        dens[[o]] <- densi
                        builder2 <- which((gDistance(SpatialPoints(points.dem), 
                          lines[[n]], byid = T) <= dist.th))
                        rough.points[[o]] <- mean(roughs.dem[builder2])
                        o = o + 1
                      }
                    }
                    liness[[j]] <- lines2
                    rough.pointss[[j]] <- rough.points
                  }
                }
                dires <- dires[-builder]
                points <- points[-builder, ]
                M.angles.per <- M.angles.per[-builder, ]
                M.roughs <- M.roughs[-builder, ]
                phi <- phi[-builder, ]
                j = j + 1
            }
        }
        linessd[[k]] <- unlist(liness)
        rough.pointssd[[k]] <- unlist(rough.pointss)
    }
    lines.fine <- unlist(linessd)
    rough.points.final <- unlist(rough.pointssd)
    return(list(lines.fine, rough.points.final))
  }
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
