\name{toporough}
\alias{toporough}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Multi directional and multi scale relief roughness filter.
}
\description{
Detects rough domains (mri) on digital elevation models and outputs additional paramatar as direction and widht of the structure.
}
\usage{
toporough(dem, type, ngbr, nform, k.diff)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{dem}{
A digital elevation model of object type RasterLayer generated by the command raster() in the raster package.
}
  \item{type}{
"min" or "max". "min" corresponds to ridge structures, "max" to valley structures.
}
  \item{ngbr}{
Numerical, odd number - defines the used maximum moving window size (n*n). Smaller moving window sizes are calculated automatically.
}
  \item{nform}{
"circ" or "qu"- defines the shape of the moving window, circular or quadratic.
}
  \item{k.diff}{
Numerical - maximum allowed slope of a straight line connecting two edge points. If NA all slopes are allowed. See details. 
}
}
\details{
The multi roughness index (mri) is calculated as the vertical elevation difference (d) between the center cell and the different orientated straight lines connecting two edge cells of a neighborhood, divided by the horizontal distance (width) of the edge cells. Thus multiple roughness values depending on the neighborhood sizes and orientations of the edge connecting lines are generated for each cell and the maximum (valley) or minimum (ridge) values are extracted. The additional parameter k represents the maximum allowed slope of the horizontal distance line (width). Slope here is calculated by the horizontal distance and elevation difference. 
}
\value{
A list of raster maps.
\item{comp1 }{Raster map of multi roughness index (mri).}
\item{comp2 }{Raster map of k values.}
\item{comp3 }{Raster map of d values.}
\item{comp4 }{Raster map of orientations.}
\item{comp5 }{Raster map of widths.}
}
\references{
}
\author{
Sebastian Baumann
}
\note{
%%  ~~further notes~~
}

\section{Warning }{Different raster resolution in x and y direction: (xres+yres)/2 has been used as overall resolution.}

\seealso{
raster
}
\examples{
data("work.data",package="lineaDEM") #import data
dem.mara<-work.data[[3]]
rough<-toporough(dem.mara,"max",11,"qu",0.5)
plot(rough[[1]]) #plot roughness map

## The function is currently defined as
function (dem, type, ngbr, nform, k.diff) 
{
    res <- (xres(dem) + yres(dem))/2
    if (yres(dem) != xres(dem)) {
        warning("Different raster resolution in x and y direction: 
        (xres+yres)/2 has been used as overall resolution.")
    }
    n.cells.raster <- length(dem[])
    ngbr.sq <- ngbr^2
    n.neigh <- (ngbr - 1)/2
    mid.coor <- (ngbr + 1)/2
    M1.dist <- matrix(1:ngbr, ncol = ngbr, nrow = ngbr, byrow = T)
    M2.dist <- matrix(1:ngbr, ncol = ngbr, nrow = ngbr)
    M.dist <- sqrt((M2.dist - M1.dist[mid.coor, mid.coor]) * 
        (M2.dist - M1.dist[mid.coor, mid.coor]) + (M1.dist - 
        M2.dist[mid.coor, mid.coor]) * (M1.dist - M2.dist[mid.coor, 
        mid.coor]))
    v.dist <- c(M.dist[1:((ngbr.sq - 1)/2)])
    M.point.x <- matrix(v.dist, ncol = ((ngbr.sq - 1)/2), nrow = n.cells.raster, 
        byrow = T)
    M.point.x <- M.point.x * res
    M.dem <- getValuesFocal(dem, ngb = ngbr, names = TRUE)
    if (nform == "circ") {
        M.dist.circ <- M.dist
        M.dist.circ[M.dist.circ[] > (ngbr - 1)/2] <- NA
        v.dist.circ <- c(M.dist.circ[1:(ngbr.sq)])
        v.dist.circ[!is.na(v.dist.circ)] <- 1
        M.dem <- t(t(M.dem) * v.dist.circ)
    }
    na.max <- function(x) ifelse(!all(is.na(x)), max(x, na.rm = T), 
        NA)
    na.min <- function(x) ifelse(!all(is.na(x)), min(x, na.rm = T), 
        NA)
    M.point.k <- (M.dem[, (ngbr.sq):(((ngbr.sq + 1)/2) + 1)] - 
        ((M.dem[, 1:(((ngbr.sq) - 1)/2)])))/(-M.point.x * 2)
    if (!is.na(k.diff)) {
        M.point.k <- ifelse(M.point.k >= -k.diff & M.point.k <= 
            k.diff, M.point.k, NA)
    }
    M.point.y <- M.dem[, (ngbr.sq):(((ngbr.sq + 1)/2) + 1)]
    M.point.d <- M.point.y - ((M.point.k * (-M.point.x)))
    M.point.d.ver <- (M.point.d - M.dem[, (ngbr.sq + 1)/2])/M.point.x/2
    if (type == "min") {
        rough <- apply(M.point.d.ver, 1, na.min)
        rough.pos <- as.numeric(apply(M.point.d.ver, 1, which.min))
    }
    else {
        rough <- apply(M.point.d.ver, 1, na.max)
        rough.pos <- as.numeric(apply(M.point.d.ver, 1, which.max))
    }
    r.rough <- dem
    r.rough[] <- rough
    r.pos <- dem
    r.pos[] <- rough.pos
    r.k <- dem
    r.k[] <- sqrt((M.point.k[cbind(1:nrow(M.point.k), rough.pos)])^2)
    r.width <- dem
    r.width[] <- M.point.x[cbind(1:nrow(M.point.x), rough.pos)] * 
        2
    r.d <- dem
    r.d[] <- M.point.d[cbind(1:nrow(M.point.d), rough.pos)]
    r.d <- r.d - dem
    v.dire <- rep(c(rep(-1, (ngbr - 1)/2), rep(1, (ngbr + 1)/2)), 
        ngbr)
    M1.dire <- matrix(((ngbr - 1)/-2):((ngbr - 1)/2), ncol = ngbr, 
        nrow = ngbr, byrow = T)
    M2.dire <- (-1) * (matrix(((ngbr - 1)/-2):((ngbr - 1)/2), 
        ncol = ngbr, nrow = ngbr))
    M.dire <- ((M2.dire)/(sqrt(M1.dire^2 + M2.dire^2)))
    M.dire <- acos(M.dire) * 180/pi
    M.dire <- t(t(M.dire) * v.dire)
    M.dire <- t(M.dire)
    v.dire <- M.dire[1:((ngbr.sq - 1)/2)]
    v.dire <- ifelse(v.dire < 0, v.dire + 180, v.dire)
    r.dire <- r.pos
    r.dire[] <- v.dire[r.pos[]]
    gc()
    return((c(r.rough, r.k, r.d, r.dire, r.width)))
  }
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
