\name{track.extrema}
\alias{track.extrema}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Tracks on RasterLayers.
}
\description{
Computes tracks on RasterLayers starting from a defined point. Uses the command adjacent() from the package raster.
}
\usage{
track.extrema(r, startpoint, ngbr, type, method, endcon)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{r}{
Object of type RasterLayer generated by the command raster() in the raster package.
}
  \item{startpoint}{
A vector of X and Y coordinates of the starting point.
}
  \item{ngbr}{
Numerical, odd number - defines the n*n neighborhood to search for the next point on the track. 
}
  \item{type}{
"min" or "max", for finding the minimum or maximum cell value within the moving window.
}
  \item{method}{
"multi" or "single":
"multi": all cells of the prior moving window are ignored in the next steps.
"single": only the used (maximum or minmum) cell is ignored in the next steps.
}
  \item{endcon}{
Numerical - endcondition to stop the track. If endcon is a number, track stops if the value of a computed track cell is lower (type="min") or greater (type="max") than endcon. If endcon is NA, track stops if the value of a computed track cell is greater (type="min") or lower (type="max") than any other trackvalue.  
}
}
\details{
track.max performs a iterate minimum or maximum search within a n*n neighborhood defined by a neighborhood size on RasterLayers. It ends if the endcon criteria is met or if a NA value occurs within the neighborhood. 
}
\value{
Returns a Matrix with X (col1) and Y (col2) coordinates of points building the track.
}
\references{
}
\author{
Sebastian Baumann
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
raster
}
\examples{
data("work.data",package="lineaDEM") #import data
accu.austria<-work.data[[2]]
track<-track.extrema(accu.austria,c(500000,220000),9,"max","multi",NA)
plot(accu.austria)
lines(track,col="blue")

## The function is currently defined as
function (r, startpoint, ngbr, type, method, endcon) 
{
    if (type == "min") {
        ext = which.min
    }
    if (type == "max") {
        ext = which.max
    }
    track <- vector()
    adj.all <- vector()
    adj <- vector()
    values <- vector()
    max.cell <- NA
    window <- matrix(1, ncol = ngbr, nrow = ngbr)
    mid.coor <- (ngbr^2 + 1)/2
    window[mid.coor] <- 0
    startcell <- cellFromXY(r, startpoint)
    i = 1
    while (!(any(is.na(values)))) {
        track[i] <- startcell
        adj <- adjacent(r, startcell, window)
        if (length(which(adj[, 2] \%in\% adj.all)) != 0) {
            adj <- adj[-which(adj[, 2] \%in\% adj.all), ]
        }
        if (length(adj) == 0) 
            break
        if (length(adj) > 2) {
            values <- (extract(r, adj[, 2]))
            ext.cell <- ext(extract(r, adj[, 2]))
            last.start.cell <- startcell
            startcell <- as.numeric(adj[ext.cell, 2])
            ext.value <- extract(r, startcell)
            last.ext.value <- extract(r, last.start.cell)
            if (method == "single") {
                adj.all <- c(adj.all, startcell, last.start.cell)
            }
            if (method == "multi") {
                adj.all <- c(adj.all, adj[, 2], startcell, last.start.cell)
            }
        }
        else {
            values <- (extract(r, adj[2]))
            ext.cell <- ext(extract(r, adj[2]))
            last.start.cell <- startcell
            startcell <- as.numeric(adj[ext.cell])
            ext.value <- extract(r, startcell)
            last.ext.value <- extract(r, last.start.cell)
            if (method == "single") {
                adj.all <- c(adj.all, startcell, last.start.cell)
            }
            if (method == "multi") {
                adj.all <- c(adj.all, adj[2], startcell, last.start.cell)
            }
        }
        i = i + 1
        if (is.numeric(endcon)) {
            if (type == "min") {
                if (ext.value < endcon) 
                  break
            }
            if (type == "max") {
                if (ext.value > endcon) 
                  break
            }
        }
        if (!is.numeric(endcon)) {
            if (type == "min") {
                if (ext.value > last.ext.value) 
                  break
            }
            if (type == "max") {
                if (ext.value < last.ext.value) 
                  break
            }
        }
    }
    track.xy <- xyFromCell(r, track)
    return(track.xy)
  }
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
